Changes
*******

0.3
----

- Add support for lookup in STATICFILES_DIRS
- Allow to use Compass

0.2
----

- Log SCSS compilation errors
- Fixed bug with paths on Windows


0.1
----

- Initial release
